@@ -30,47 +30,54 @@ def lastname_en():
     some_prefixes = [
         'Mir',
         'Agha',
+        'Abou',
         'Pour',
         'Nour',
+        'Seyed',
         'Amir',
+        'Aziz',
         'Shah',
         'Haj',
         'Haji',
         'Sheikh',
         'Mirza',
-        'Beig'
+        'Beig',
+        'Arab'
     ]
     some_suffixes = [
-        '', '', '', '', '', '', '', '', '', '', '', '', '', '', '',
-        'pour',
-        'zadeh',
-        'far',
-        'fard',
-        'an',
-        'kia',
-        'rad',
-        'zand',
-        'khah',
-        'nia',
-        'mehr',
-        'azar',
-        'nejad',
-        'bayat',
-        'yekta'
+        'pour', '',
+        'zadeh', '',
+        'far', '',
+        'fard', '',
+        'an', '',
+        'kia', '',
+        'rad', '',
+        'zand', '',
+        'khah', '',
+        'nia', '',
+        'mehr', '',
+        'azar', '',
+        'sadr', '',
+        'kohan', '',
+        'nejad', '',
+        'bayat', '',
+        'yekta' '',
+        'azad', '',
+        'zare', '',
     ]
     more_suffixes = [
-        'i', 'i', 'i', 'i', 'i', 'i', 'i', 'i', 'i', 'i', 'i',
-        'pour',
-        'zadeh',
-        'far',
-        'fard',
-        'khani',
-        'vand',
-        'lou',
-        'nia',
-        'zehi',
-        'nejad',
-        'beigi'
+        'pour', 'i',
+        'zadeh', 'i',
+        'far', 'i',
+        'fard', 'i',
+        'khani', 'i',
+        'vand', 'i',
+        'lou', 'i',
+        'nia', 'i',
+        'zehi', 'i',
+        'nejad', 'i',
+        'beigi', 'i',
+        'zare', 'i',
     ]
     some_names = []
 
@@ -150,47 +157,54 @@ def lastname_fa():
     some_prefixes = [
         'میر',
         'آقا',
+        'ابو',
         'پور',
         'نور',
+        'سید',
         'امیر',
+        'عزیز',
         'شاه ',
         'حاج ',
         'حاجی ',
         'شیخ ',
         'میرزا ',
-        'بیگ '
+        'بیگ ',
+        'عرب '
     ]
     some_suffixes = [
-        '', '', '', '', '', '', '', '', '', '', '', '', '', '', '',
-        ' پور',
-        ' زاده',
-        ' فر',
-        ' فرد',
-        'ان',
-        ' کیا',
-        ' راد',
-        ' زند',
-        ' خواه',
-        ' نیا',
-        ' مهر',
-        ' آذر',
-        ' نژاد',
-        ' بیات',
-        ' یکتا'
+        ' پور', '',
+        ' زاده', '',
+        ' فر', '',
+        ' فرد', '',
+        'ان', '',
+        ' کیا', '',
+        ' راد', '',
+        ' زند', '',
+        ' خواه', '',
+        ' نیا', '',
+        ' مهر', '',
+        ' آذر', '',
+        ' صدر', '',
+        ' کهن', '',
+        ' نژاد', '',
+        ' بیات', '',
+        ' یکتا', '',
+        ' آزاد', '',
+        ' زارع', '',
     ]
     more_suffixes = [
-        'ی', 'ی', 'ی', 'ی', 'ی', 'ی', 'ی', 'ی', 'ی', 'ی', 'ی',
-        ' پور',
-        ' زاده',
-        ' فر',
-        ' فرد',
-        ' خانی',
-        ' وند',
-        ' لو',
-        ' نیا',
-        ' زهی',
-        ' نژاد',
-        ' بیگی'
+        ' پور', 'ی',
+        ' زاده', 'ی',
+        ' فر', 'ی',
+        ' فرد', 'ی',
+        ' خانی', 'ی',
+        ' وند', 'ی',
+        ' لو', 'ی',
+        ' نیا', 'ی',
+        ' زهی', 'ی',
+        ' نژاد', 'ی',
+        ' بیگی', 'ی',
+        ' زارع', 'ی',
     ]
     some_names = []
 
